aboutsummaryrefslogtreecommitdiff
path: root/common
diff options
context:
space:
mode:
Diffstat (limited to 'common')
-rw-r--r--common/system.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/common/system.h b/common/system.h
index 34b9275079..96f4378490 100644
--- a/common/system.h
+++ b/common/system.h
@@ -285,12 +285,12 @@ public:
/**
* Start audio CD playback.
* @param track the track to play.
* @param num_loops how often playback should be repeated (-1 = infinitely often).
* @param start the frame at which playback should start (75 frames = 1 second).
* @param duration the number of frames to play.
*/
- virtual void play_cdrom(int track, int num_loops, int start, int duration) = 0;
+ virtual void play_cdrom(int track, int num_loops, int start_frame, int duration) = 0;
/**
// Stop audio CD playback
@@ -285,12 +285,12 @@ public:
/**
* Start audio CD playback.
- * @param track the track to play.
- * @param num_loops how often playback should be repeated (-1 = infinitely often).
- * @param start the frame at which playback should start (75 frames = 1 second).
- * @param duration the number of frames to play.
+ * @param track the track to play.
+ * @param num_loops how often playback should be repeated (-1 = infinitely often).
+ * @param start_frame the frame at which playback should start (75 frames = 1 second).
+ * @param duration the number of frames to play.
*/